@@ -84,12 +84,10 @@ class CommeoSenderWriteManual(Command):
         self.executed = bool(methodResponse.parameters[0][1])
         
 class SenderDevice(Device):
-    def __init__(self, gateway, id, discover = False):
-        super().__init__(gateway, id, discover)
+    def __init__(self, gateway, id):
+        super().__init__(gateway, id)
         self.communicationType = CommunicationType.COMMEO
         self.deviceClass = DeviceClass.SENDER
-        if discover:
-            self.discover_properties()
 
     def discover_properties(self):
         try:
